@@ -1,18 +1,22 @@
 /* This is part of `gramscii`` -- see COPYING for details */
+#ifndef __LOCAL_CONFIG_H__
+#define __LOCAL_CONFIG_H__
 
 /* Config options */
 
 /** MARKERS -- the first character is the default one **/
 /* markers for horizontal lines */
-char hlines[]  = {"-~=#*@._ "};
+static char hlines[]  = {"-~=#*@._ "};
 /* markers for vertical lines */
-char vlines[]  = {"|H#*@:;i "};
+static char vlines[]  = {"|H#*@:;i "};
 /* markers for corners */
-char corners[] = {"+'H#*@.\"`"};
+static char corners[] = {"+'H#*@.\"`"};
 /* markers for arrow start points */
-char st_marks[] = {"+o-|<>^v*"};
+static char st_marks[] = {"+o-|<>^v*"};
 /* markers for arrow endpoints */
-char end_marks[] = {">+o-|<^v*"};
+static char end_marks[] = {">+o-|<^v*"};
 
 /** LONG_STEP (movements through uppercase HJKL) **/
 #define LONG_STEP 5
+
+#endif
